@@ -3,15 +3,18 @@
 Copyright (c) 2000-2003 Ng Pheng Siong. All rights reserved.
 This software is released under the ZPL. Usual disclaimers apply."""
 
-RCS_id = '$Id: GuardedFile.py 299 2005-06-09 17:32:28Z heikki $'
-__version__ = '$Revision: 1.3 $'[11:-2]
+__version__ = "1.3"
 
 from AccessControl import getSecurityManager
 from Globals import HTMLFile, MessageDialog
 from OFS.Image import File, cookId
 
-manage_addForm = HTMLFile('add', globals(),Kind='GuardedFile',kind='GuardedFile')
-def manage_addGuardedFile(self, id, file, title='', precondition='', content_type='', REQUEST=None):
+manage_addForm = HTMLFile("add", globals(), Kind="GuardedFile", kind="GuardedFile")
+
+
+def manage_addGuardedFile(
+    self, id, file, title="", precondition="", content_type="", REQUEST=None
+):
     """
     Add a new GuardedFile object.
 
@@ -20,7 +23,7 @@ def manage_addGuardedFile(self, id, file, title='', precondition='', content_typ
     # Object creation stuff, cribbed from OFS.Image.manage_addFile().
     id, title = cookId(id, title, file)
     self = self.this()
-    self._setObject(id, GuardedFile(id, title, '', content_type, precondition))
+    self._setObject(id, GuardedFile(id, title, "", content_type, precondition))
     obj = self._getOb(id)
     obj.manage_upload(file)
 
@@ -30,19 +33,22 @@ def manage_addGuardedFile(self, id, file, title='', precondition='', content_typ
     # Create a proxy role and set a specific permission for it.
     proxy_role = "proxy_for_%s" % id
     self._addRole(proxy_role)
-    obj.manage_role(proxy_role, ['View'])
+    obj.manage_role(proxy_role, ["View"])
     uname = getSecurityManager().getUser().getUserName()
     self.manage_addLocalRoles(uname, (proxy_role,), REQUEST)
 
     # Feedback.
-    if REQUEST: return MessageDialog(
-        title  ='Success!',
-        message='GuardedFile "%s" has been created.' % id,
-        action ='manage_main')
-        
+    if REQUEST:
+        return MessageDialog(
+            title="Success!",
+            message='GuardedFile "%s" has been created.' % id,
+            action="manage_main",
+        )
+
 
 class GuardedFile(File):
     """A File object accessible by proxy only."""
+
     meta_type = "GuardedFile"
 
     def manage_beforeDelete(self, item, container):
@@ -50,5 +56,3 @@ class GuardedFile(File):
         role = "proxy_for_%s" % self.__name__
         container._delRoles([role], None)
         self.manage_delLocalRoles(self.users_with_local_role(role))
- 
-
